@@ -31,7 +31,8 @@ class GMXTrjConvStr():
             * **container_shell_path** (*str*) - ('/bin/bash') Path to default shell inside the container.
     """
 
-    def __init__(self, input_structure_path, input_top_path, output_str_path, input_index_path=None, properties=None, **kwargs):
+    def __init__(self, input_structure_path, input_top_path, 
+                 output_str_path, input_index_path=None, properties=None, **kwargs) -> None:
         properties = properties or {}
 
         # Input/Output files
@@ -75,7 +76,7 @@ class GMXTrjConvStr():
             self.selection = get_selection_index_file(self.properties, self.io_dict["in"]["input_index_path"], 'selection', out_log, self.__class__.__name__)
 
     @launchlogger
-    def launch(self):
+    def launch(self) -> int:
         """Launches the execution of the GROMACS rgyr module."""
         
         # Get local loggers from launchlogger decorator
